@@ -6,13 +6,14 @@
             "diag"=0.05,
             "verbose"=1,
             "LB"=FALSE,
-            "RNG"="none"))
+            "RNG"="none",
+            "overwrite"=FALSE))
     rj <- suppressWarnings(require(rjags))
     if (!rj)
         cat("Warning message:\n  there is no package called 'rjags'\n")
     ver <- read.dcf(file=system.file("DESCRIPTION", package=pkgname), 
         fields=c("Version", "Date"))
-    cat(paste(pkgname, ver[1], "\t", ver[2], "\n"))
+    packageStartupMessage(paste(pkgname, ver[1], "\t", ver[2], "\n"))
     invisible(NULL)
 }
 
